package gLite::VOMS;

require 5.006;

use strict;
no strict 'refs';
use SOAP::Lite;
use gLite::HTTPS;

my $VOMS_NS  = 'http://glite.org/wsdl/services/org.glite.security.voms';
my $VOMS_ATTRIBUTE_NS = 'http://glite.org/wsdl/services/org.glite.security.voms.service.attributes';

=pod

=head1 NAME

gLite::VOMS

=head1 DESCRIPTION

Common utilities to connect to a VOMS server.

=over 4

=item B<connect($interface, $url)>

The B<connect()> function creates a new SOAP::Lite object, which is configured
to communicate with the remote I<$interface> service at I<$url>.

Possible values for the B<$interface>: I<VOMSAdmin>, I<VOMSCore>, 
I<VOMSCompatibility>, I<VOMSHistory> and I<VOMSRequest>.

An example of a B<$url>: C<https://voms.server.xx:8443/voms/fred>

=back

=head1 AUTHORS

�kos Frohner <Akos.Frohner@cern.ch>, K�roly Lorentey <Lorentey.Karoly@elte.hu>

Copyright (c) 2003 CERN, ELTE, on behalf of the EU DataGrid project.
For license conditions see LICENSE file or
L<http://www.edg.org/license.html>.

=cut

# define the proxy according to the command line parameters
sub connect {
	my ($interface, $url) = @_;

	die "Unknown interface: $interface\n"
	   unless $interface =~ /^VOMS(Admin|Core|Compatibility|History|Request|Attributes)$/;
	
	die "Unknown URL!\n" unless defined $url;
	
	# split up the proxy and configure the environment
	gLite::HTTPS::setEnv() if $url =~ /^https:/i;

	my $admin = new SOAP::Lite
#	uri => 'urn:voms-admin',
	uri => 'urn:VOMS',
#	service => 'file:../build/soap/wsdl/voms-admin.wsdl',
	proxy => "$url/services/$interface",
	on_fault => sub { 
	    my($soap, $res) = @_;
	    die $soap->transport->status . "\n" unless (ref $res);
	    
	    #print $res->faultdetail()->{stackTrace}, "\n";
	    if (defined $res->faultdetail()->{exceptionName}) {
		die $res->faultdetail()->{exceptionName} . ": " . $res->faultstring() . "\n";
	    }
	    else {
		die $res->faultstring() . "\n";
	    }
	};


	$admin->serializer()->maptype->{'User'} = $VOMS_NS;
	$admin->serializer()->maptype->{'ACLEntry'} = $VOMS_NS;
	$admin->serializer()->maptype->{'QalifiedRole'} = $VOMS_NS;
	$admin->serializer()->maptype->{'Attribute'} = $VOMS_ATTRIBUTE_NS;

	return $admin;
}

1;

# Please do not change this line. 
# arch-tag: 70fc5c0f-240b-41a6-9b96-e312847acfc5
